@@ -29,7 +29,7 @@
     MMM => "LLL",
     MMMEd => "E, MMM d",
     "MMMMW-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
-    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMM",
+    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
@@ -268,5 +268,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 33,
+  version => 35,
 }
