@@ -32,10 +32,10 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-few" => "MMM, 'tydz'. W",
-    "MMMMW-count-many" => "MMM, 'tydz'. W",
-    "MMMMW-count-one" => "MMM, 'tydz'. W",
-    "MMMMW-count-other" => "MMM, 'tydz'. W",
+    "MMMMW-count-few" => "MMMM, 'tydz'. W",
+    "MMMMW-count-many" => "MMMM, 'tydz'. W",
+    "MMMMW-count-one" => "MMMM, 'tydz'. W",
+    "MMMMW-count-other" => "MMMM, 'tydz'. W",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d.MM",
@@ -278,5 +278,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 35,
 }
