@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "e paradites",
-    "e pasdites",
+    "p.d.",
+    "m.d.",
   ],
   available_formats => {
     Bh => "h B",
@@ -29,8 +29,8 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-one" => "'java' W 'e' MMM",
-    "MMMMW-count-other" => "'java' W 'e' MMM",
+    "MMMMW-count-one" => "'java' W 'e' MMMM",
+    "MMMMW-count-other" => "'java' W 'e' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "d.M",
@@ -74,13 +74,13 @@
     "Die",
   ],
   day_format_narrow => [
-    "H",
-    "M",
-    "M",
-    "E",
-    "P",
-    "Sh",
-    "D",
+    "h",
+    "m",
+    "m",
+    "e",
+    "p",
+    "sh",
+    "d",
   ],
   day_format_wide => [
     "e h\N{U+00eb}n\N{U+00eb}",
@@ -92,31 +92,31 @@
     "e diel",
   ],
   day_stand_alone_abbreviated => [
-    "H\N{U+00eb}n",
-    "Mar",
-    "M\N{U+00eb}r",
-    "Enj",
-    "Pre",
-    "Sht",
-    "Die",
+    "h\N{U+00eb}n",
+    "mar",
+    "m\N{U+00eb}r",
+    "enj",
+    "pre",
+    "sht",
+    "die",
   ],
   day_stand_alone_narrow => [
-    "H",
-    "M",
-    "M",
-    "E",
-    "P",
-    "Sh",
-    "D",
+    "h",
+    "m",
+    "m",
+    "e",
+    "p",
+    "sh",
+    "d",
   ],
   day_stand_alone_wide => [
-    "E h\N{U+00eb}n\N{U+00eb}",
-    "E mart\N{U+00eb}",
-    "E m\N{U+00eb}rkur\N{U+00eb}",
-    "E enjte",
-    "E premte",
-    "E shtun\N{U+00eb}",
-    "E diel",
+    "e h\N{U+00eb}n\N{U+00eb}",
+    "e mart\N{U+00eb}",
+    "e m\N{U+00eb}rkur\N{U+00eb}",
+    "e enjte",
+    "e premte",
+    "e shtun\N{U+00eb}",
+    "e diel",
   ],
   era_abbreviated => [
     "p.K.",
@@ -180,46 +180,46 @@
     "dhjetor",
   ],
   month_stand_alone_abbreviated => [
-    "Jan",
-    "Shk",
-    "Mar",
-    "Pri",
-    "Maj",
-    "Qer",
-    "Korr",
-    "Gush",
-    "Sht",
-    "Tet",
-    "N\N{U+00eb}n",
-    "Dhj",
+    "jan",
+    "shk",
+    "mar",
+    "pri",
+    "maj",
+    "qer",
+    "korr",
+    "gush",
+    "sht",
+    "tet",
+    "n\N{U+00eb}n",
+    "dhj",
   ],
   month_stand_alone_narrow => [
-    "J",
-    "Sh",
-    "M",
-    "P",
-    "M",
-    "Q",
-    "K",
-    "G",
-    "Sh",
-    "T",
-    "N",
-    "Dh",
+    "j",
+    "sh",
+    "m",
+    "p",
+    "m",
+    "q",
+    "k",
+    "g",
+    "sh",
+    "t",
+    "n",
+    "dh",
   ],
   month_stand_alone_wide => [
-    "Janar",
-    "Shkurt",
-    "Mars",
-    "Prill",
-    "Maj",
-    "Qershor",
-    "Korrik",
-    "Gusht",
-    "Shtator",
-    "Tetor",
-    "N\N{U+00eb}ntor",
-    "Dhjetor",
+    "janar",
+    "shkurt",
+    "mars",
+    "prill",
+    "maj",
+    "qershor",
+    "korrik",
+    "gusht",
+    "shtator",
+    "tetor",
+    "n\N{U+00eb}ntor",
+    "dhjetor",
   ],
   name => "Albanian",
   native_language => "shqip",
@@ -270,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 32,
+  version => 35,
 }
