@@ -130,10 +130,10 @@
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%m/%d/%y",
-  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
-  glibc_time_12_format => "%I:%M:%S %p",
-  glibc_time_format => "%H:%M:%S",
+  glibc_date_format => "%A %d %b %Y",
+  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p %Z",
+  glibc_time_12_format => "%I:%M:%S %p %Z",
+  glibc_time_format => "%I:%M:%S %Z",
   language => "Tongan",
   month_format_abbreviated => [
     "S\N{U+0101}n",
@@ -268,5 +268,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 32,
+  version => 35,
 }
